@@ -51,6 +51,8 @@
 
 NJD_SET_DIGIT_RULE_H_START;
 
+#define NJD_SET_DIGIT_KIGOU "\xb5\xad\xb9\xe6"
+#define NJD_SET_DIGIT_MEISHI "\xcc\xbe\xbb\xec"
 #define NJD_SET_DIGIT_KAZU "\xbf\xf4"
 #define NJD_SET_DIGIT_SUUSETSUZOKU "\xbf\xf4\xc0\xdc\xc2\xb3"
 #define NJD_SET_DIGIT_JOSUUSHI "\xbd\xf5\xbf\xf4\xbb\xec"
@@ -63,6 +65,7 @@ NJD_SET_DIGIT_RULE_H_START;
 #define NJD_SET_DIGIT_KAKKO1 "\xa1\xca"
 #define NJD_SET_DIGIT_KAKKO2 "\xa1\xcb"
 #define NJD_SET_DIGIT_BANGOU "\xc8\xd6\xb9\xe6"
+#define NJD_SET_DIGIT_COMMA "\xa1\xa4"
 #define NJD_SET_DIGIT_TEN1 "\xa1\xa5"
 #define NJD_SET_DIGIT_TEN2 "\xa1\xa6"
 #define NJD_SET_DIGIT_TEN_FEATURE "\xa1\xa5,\xcc\xbe\xbb\xec,\xc0\xdc\xc8\xf8,\xbd\xf5\xbf\xf4\xbb\xec,*,*,*,\xa1\xa5,\xa5\xc6\xa5\xf3,\xa5\xc6\xa5\xf3,0/2,*,-1"
@@ -76,6 +79,7 @@ NJD_SET_DIGIT_RULE_H_START;
 #define NJD_SET_DIGIT_FIVE "\xb8\xde"
 #define NJD_SET_DIGIT_FIVE_BEFORE_DP "\xa5\xb4\xa1\xbc"
 #define NJD_SET_DIGIT_FIVE_AFTER_DP "\xa5\xb4\xa1\xbc"
+#define NJD_SET_DIGIT_SIX "\xcf\xbb"
 #define NJD_SET_DIGIT_NIN "\xbf\xcd"
 #define NJD_SET_DIGIT_GATSU "\xb7\xee"
 #define NJD_SET_DIGIT_NICHI "\xc6\xfc"
@@ -305,7 +309,7 @@ static const char *njd_set_digit_rule_numerative_class1g[] = {
    "\xb2\xc1", "\xb2\xdd", "\xb2\xe8", "\xb2\xf3", "\xb2\xf3\xb4\xf7", "\xb2\xf3\xc0\xb8", "\xb2\xf3\xc0\xef", "\xb2\xf3\xc0\xfe", "\xb2\xf3\xca\xac", "\xb3\xa4\xce\xa4", "\xa5\xab\xa5\xa4\xa5\xea", "\xb3\xbd", "\xb3\xd1",
    "\xb3\xf4", "\xb4\xa7", "\xb4\xac", "\xb4\xcc", "\xb4\xd3", "\xb4\xd3\xcc\xdc", "\xb4\xd6", "\xb4\xf0", "\xb4\xfc", "\xb4\xfc\xc0\xb8", "\xb5\xa1", "\xb5\xa4\xb0\xb5", "\xb5\xa8", "\xb5\xb3",
    "\xb5\xd2", "\xb5\xd3", "\xb5\xe5", "\xb5\xe9", "\xb6\xb6", "\xb6\xc9", "\xb6\xca", "\xb6\xcb", "\xbd\xc5\xa4\xcd", "\xb6\xd4", "\xb6\xe2", "\xb6\xe7", "\xb6\xe8", "\xb6\xed", "\xb7\xd7",
-   "\xb7\xe5", "\xa5\xb1\xa5\xbf", "\xb9\xbb", "\xb9\xc1", "\xb9\xd4", "\xb9\xe0", "\xc1\xc8", "\xb7\xef", "\xb8\xae", "\xb8\xc0", "\xb8\xcd", "\xb8\xd0", "\xb8\xf7\xc7\xaf", "\xc0\xd0",
+   "\xb7\xe5", "\xa5\xb1\xa5\xbf", "\xb9\xbb", "\xb9\xc1", /* "\xb9\xd4", */ "\xb9\xe0", "\xc1\xc8", "\xb7\xef", "\xb8\xae", "\xb8\xc0", "\xb8\xcd", "\xb8\xd0", "\xb8\xf7\xc7\xaf", "\xc0\xd0",
    "\xa4\xd4\xa4\xad", "\xa4\xda\xa4\xf3", "\xc7\xc8", "\xc7\xc9", "\xc7\xd4", "\xc7\xd5", "\xc7\xef", "\xc7\xf1", "\xc8\xc7", "\xc8\xc8", "\xc8\xc9", "\xc9\xa4", "\xc9\xa5", "\xc9\xae", "\xc9\xb6",
    "\xc9\xbc", "\xc9\xca", "\xca\xac\xb4\xd6", "\xca\xac\xcc\xdc", "\xca\xd2", "\xca\xd2", "\xca\xd3", "\xca\xd4", "\xca\xd5", "\xca\xd7", "\xca\xe2", "\xca\xe2", "\xca\xf3", "\xca\xfd", "\xca\xfd",
    "\xcb\xa1", "\xcb\xdc\xce\xa9\xa4\xc6", "\xc6\xac\xbf\xc8",
