@@ -51,6 +51,8 @@
 
 NJD_SET_DIGIT_RULE_H_START;
 
+#define NJD_SET_DIGIT_KIGOU "\x8b\x4c\x8d\x86"
+#define NJD_SET_DIGIT_MEISHI "\x96\xbc\x8e\x8c"
 #define NJD_SET_DIGIT_KAZU "\x90\x94"
 #define NJD_SET_DIGIT_SUUSETSUZOKU "\x90\x94\x90\xda\x91\xb1"
 #define NJD_SET_DIGIT_JOSUUSHI "\x8f\x95\x90\x94\x8e\x8c"
@@ -63,6 +65,7 @@ NJD_SET_DIGIT_RULE_H_START;
 #define NJD_SET_DIGIT_KAKKO1 "\x81\x69"
 #define NJD_SET_DIGIT_KAKKO2 "\x81\x6a"
 #define NJD_SET_DIGIT_BANGOU "\x94\xd4\x8d\x86"
+#define NJD_SET_DIGIT_COMMA "\x81\x43"
 #define NJD_SET_DIGIT_TEN1 "\x81\x44"
 #define NJD_SET_DIGIT_TEN2 "\x81\x45"
 #define NJD_SET_DIGIT_TEN_FEATURE "\x81\x44,\x96\xbc\x8e\x8c,\x90\xda\x94\xf6,\x8f\x95\x90\x94\x8e\x8c,*,*,*,\x81\x44,\x83\x65\x83\x93,\x83\x65\x83\x93,0/2,*,-1"
@@ -76,6 +79,7 @@ NJD_SET_DIGIT_RULE_H_START;
 #define NJD_SET_DIGIT_FIVE "\x8c\xdc"
 #define NJD_SET_DIGIT_FIVE_BEFORE_DP "\x83\x53\x81\x5b"
 #define NJD_SET_DIGIT_FIVE_AFTER_DP "\x83\x53\x81\x5b"
+#define NJD_SET_DIGIT_SIX "\x98\x5a"
 #define NJD_SET_DIGIT_NIN "\x90\x6c"
 #define NJD_SET_DIGIT_GATSU "\x8c\x8e"
 #define NJD_SET_DIGIT_NICHI "\x93\xfa"
@@ -305,7 +309,7 @@ static const char *njd_set_digit_rule_numerative_class1g[] = {
    "\x89\xbf", "\x89\xdb", "\x89\xe6", "\x89\xf1", "\x89\xf1\x8a\xf5", "\x89\xf1\x90\xb6", "\x89\xf1\x90\xed", "\x89\xf1\x90\xfc", "\x89\xf1\x95\xaa", "\x8a\x43\x97\xa2", "\x83\x4a\x83\x43\x83\x8a", "\x8a\x5c", "\x8a\x70",
    "\x8a\x94", "\x8a\xa5", "\x8a\xaa", "\x8a\xca", "\x8a\xd1", "\x8a\xd1\x96\xda", "\x8a\xd4", "\x8a\xee", "\x8a\xfa", "\x8a\xfa\x90\xb6", "\x8b\x40", "\x8b\x43\x88\xb3", "\x8b\x47", "\x8b\x52",
    "\x8b\x71", "\x8b\x72", "\x8b\x85", "\x8b\x89", "\x8b\xb4", "\x8b\xc7", "\x8b\xc8", "\x8b\xc9", "\x8f\x64\x82\xcb", "\x8b\xd2", "\x8b\xe0", "\x8b\xe5", "\x8b\xe6", "\x8b\xeb", "\x8c\x76",
-   "\x8c\x85", "\x83\x50\x83\x5e", "\x8d\x5a", "\x8d\x60", "\x8d\x73", "\x8d\x80", "\x91\x67", "\x8c\x8f", "\x8c\xac", "\x8c\xbe", "\x8c\xcb", "\x8c\xce", "\x8c\xf5\x94\x4e", "\x90\xce",
+   "\x8c\x85", "\x83\x50\x83\x5e", "\x8d\x5a", "\x8d\x60", /* "\x8d\x73", */ "\x8d\x80", "\x91\x67", "\x8c\x8f", "\x8c\xac", "\x8c\xbe", "\x8c\xcb", "\x8c\xce", "\x8c\xf5\x94\x4e", "\x90\xce",
    "\x82\xd2\x82\xab", "\x82\xd8\x82\xf1", "\x94\x67", "\x94\x68", "\x94\x73", "\x94\x74", "\x94\x8f", "\x94\x91", "\x94\xc5", "\x94\xc6", "\x94\xc7", "\x95\x43", "\x95\x44", "\x95\x4d", "\x95\x55",
    "\x95\x5b", "\x95\x69", "\x95\xaa\x8a\xd4", "\x95\xaa\x96\xda", "\x95\xd0", "\x95\xd0", "\x95\xd1", "\x95\xd2", "\x95\xd3", "\x95\xd5", "\x95\xe0", "\x95\xe0", "\x95\xf1", "\x95\xfb", "\x95\xfb",
    "\x96\x40", "\x96\x7b\x97\xa7\x82\xc4", "\x93\xaa\x90\x67",
