@@ -51,6 +51,8 @@
 
 NJD_SET_DIGIT_RULE_H_START;
 
+#define NJD_SET_DIGIT_KIGOU "\xe8\xa8\x98\xe5\x8f\xb7"
+#define NJD_SET_DIGIT_MEISHI "\xe5\x90\x8d\xe8\xa9\x9e"
 #define NJD_SET_DIGIT_KAZU "\xe6\x95\xb0"
 #define NJD_SET_DIGIT_SUUSETSUZOKU "\xe6\x95\xb0\xe6\x8e\xa5\xe7\xb6\x9a"
 #define NJD_SET_DIGIT_JOSUUSHI "\xe5\x8a\xa9\xe6\x95\xb0\xe8\xa9\x9e"
@@ -63,6 +65,7 @@ NJD_SET_DIGIT_RULE_H_START;
 #define NJD_SET_DIGIT_KAKKO1 "\xef\xbc\x88"
 #define NJD_SET_DIGIT_KAKKO2 "\xef\xbc\x89"
 #define NJD_SET_DIGIT_BANGOU "\xe7\x95\xaa\xe5\x8f\xb7"
+#define NJD_SET_DIGIT_COMMA "\xef\xbc\x8c"
 #define NJD_SET_DIGIT_TEN1 "\xef\xbc\x8e"
 #define NJD_SET_DIGIT_TEN2 "\xe3\x83\xbb"
 #define NJD_SET_DIGIT_TEN_FEATURE "\xef\xbc\x8e,\xe5\x90\x8d\xe8\xa9\x9e,\xe6\x8e\xa5\xe5\xb0\xbe,\xe5\x8a\xa9\xe6\x95\xb0\xe8\xa9\x9e,*,*,*,\xef\xbc\x8e,\xe3\x83\x86\xe3\x83\xb3,\xe3\x83\x86\xe3\x83\xb3,0/2,*,-1"
@@ -76,6 +79,7 @@ NJD_SET_DIGIT_RULE_H_START;
 #define NJD_SET_DIGIT_FIVE "\xe4\xba\x94"
 #define NJD_SET_DIGIT_FIVE_BEFORE_DP "\xe3\x82\xb4\xe3\x83\xbc"
 #define NJD_SET_DIGIT_FIVE_AFTER_DP "\xe3\x82\xb4\xe3\x83\xbc"
+#define NJD_SET_DIGIT_SIX "\xe5\x85\xad"
 #define NJD_SET_DIGIT_NIN "\xe4\xba\xba"
 #define NJD_SET_DIGIT_GATSU "\xe6\x9c\x88"
 #define NJD_SET_DIGIT_NICHI "\xe6\x97\xa5"
@@ -305,7 +309,7 @@ static const char *njd_set_digit_rule_numerative_class1g[] = {
    "\xe4\xbe\xa1", "\xe8\xaa\xb2", "\xe7\x94\xbb", "\xe5\x9b\x9e", "\xe5\x9b\x9e\xe5\xbf\x8c", "\xe5\x9b\x9e\xe7\x94\x9f", "\xe5\x9b\x9e\xe6\x88\xa6", "\xe5\x9b\x9e\xe7\xb7\x9a", "\xe5\x9b\x9e\xe5\x88\x86", "\xe6\xb5\xb7\xe9\x87\x8c", "\xe3\x82\xab\xe3\x82\xa4\xe3\x83\xaa", "\xe6\xb5\xac", "\xe8\xa7\x92",
    "\xe6\xa0\xaa", "\xe5\x86\xa0", "\xe5\xb7\xbb", "\xe7\xbc\xb6", "\xe8\xb2\xab", "\xe8\xb2\xab\xe7\x9b\xae", "\xe9\x96\x93", "\xe5\x9f\xba", "\xe6\x9c\x9f", "\xe6\x9c\x9f\xe7\x94\x9f", "\xe6\xa9\x9f", "\xe6\xb0\x97\xe5\x9c\xa7", "\xe5\xad\xa3", "\xe9\xa8\x8e",
    "\xe5\xae\xa2", "\xe8\x84\x9a", "\xe7\x90\x83", "\xe7\xb4\x9a", "\xe6\xa9\x8b", "\xe5\xb1\x80", "\xe6\x9b\xb2", "\xe6\xa5\xb5", "\xe9\x87\x8d\xe3\x81\xad", "\xe6\x96\xa4", "\xe9\x87\x91", "\xe5\x8f\xa5", "\xe5\x8c\xba", "\xe8\xba\xaf", "\xe8\xa8\x88",
-   "\xe6\xa1\x81", "\xe3\x82\xb1\xe3\x82\xbf", "\xe6\xa0\xa1", "\xe6\xb8\xaf", "\xe8\xa1\x8c", "\xe9\xa0\x85", "\xe7\xb5\x84", "\xe4\xbb\xb6", "\xe8\xbb\x92", "\xe8\xa8\x80", "\xe6\x88\xb8", "\xe6\xb9\x96", "\xe5\x85\x89\xe5\xb9\xb4", "\xe7\x9f\xb3",
+   "\xe6\xa1\x81", "\xe3\x82\xb1\xe3\x82\xbf", "\xe6\xa0\xa1", "\xe6\xb8\xaf", /* "\xe8\xa1\x8c", */ "\xe9\xa0\x85", "\xe7\xb5\x84", "\xe4\xbb\xb6", "\xe8\xbb\x92", "\xe8\xa8\x80", "\xe6\x88\xb8", "\xe6\xb9\x96", "\xe5\x85\x89\xe5\xb9\xb4", "\xe7\x9f\xb3",
    "\xe3\x81\xb4\xe3\x81\x8d", "\xe3\x81\xba\xe3\x82\x93", "\xe6\xb3\xa2", "\xe6\xb4\xbe", "\xe6\x95\x97", "\xe6\x9d\xaf", "\xe6\x8b\x8d", "\xe6\xb3\x8a", "\xe7\x89\x88", "\xe7\x8a\xaf", "\xe7\x8f\xad", "\xe5\x8c\xb9", "\xe7\x96\x8b", "\xe7\xad\x86", "\xe4\xbf\xb5",
    "\xe7\xa5\xa8", "\xe5\x93\x81", "\xe5\x88\x86\xe9\x96\x93", "\xe5\x88\x86\xe7\x9b\xae", "\xe7\x89\x87", "\xe7\x89\x87", "\xe7\xaf\x87", "\xe7\xb7\xa8", "\xe8\xbe\xba", "\xe9\x81\x8d", "\xe6\xad\xa9", "\xe6\xad\xa9", "\xe5\xa0\xb1", "\xe6\x96\xb9", "\xe6\x96\xb9",
    "\xe6\xb3\x95", "\xe6\x9c\xac\xe7\xab\x8b\xe3\x81\xa6", "\xe9\xa0\xad\xe8\xba\xab",
