@@ -51,6 +51,8 @@
 
 NJD_SET_DIGIT_RULE_H_START;
 
+#define NJD_SET_DIGIT_KIGOU ""
+#define NJD_SET_DIGIT_MEISHI "̾"
 #define NJD_SET_DIGIT_KAZU ""
 #define NJD_SET_DIGIT_SUUSETSUZOKU "³"
 #define NJD_SET_DIGIT_JOSUUSHI ""
@@ -63,6 +65,7 @@ NJD_SET_DIGIT_RULE_H_START;
 #define NJD_SET_DIGIT_KAKKO1 ""
 #define NJD_SET_DIGIT_KAKKO2 ""
 #define NJD_SET_DIGIT_BANGOU "ֹ"
+#define NJD_SET_DIGIT_COMMA ""
 #define NJD_SET_DIGIT_TEN1 ""
 #define NJD_SET_DIGIT_TEN2 ""
 #define NJD_SET_DIGIT_TEN_FEATURE ",̾,,,*,*,*,,ƥ,ƥ,0/2,*,-1"
@@ -76,6 +79,7 @@ NJD_SET_DIGIT_RULE_H_START;
 #define NJD_SET_DIGIT_FIVE ""
 #define NJD_SET_DIGIT_FIVE_BEFORE_DP ""
 #define NJD_SET_DIGIT_FIVE_AFTER_DP ""
+#define NJD_SET_DIGIT_SIX "ϻ"
 #define NJD_SET_DIGIT_NIN ""
 #define NJD_SET_DIGIT_GATSU ""
 #define NJD_SET_DIGIT_NICHI ""
@@ -305,7 +309,7 @@ static const char *njd_set_digit_rule_numerative_class1g[] = {
    "", "", "", "", "", "", "", "", "ʬ", "Τ", "", "", "",
    "", "", "", "", "", "", "", "", "", "", "", "", "", "",
    "", "", "", "", "", "", "", "", "Ť", "", "", "", "", "", "",
-   "", "", "", "", "", "", "", "", "", "", "", "", "ǯ", "",
+   "", "", "", "", /* "", */ "", "", "", "", "", "", "", "ǯ", "",
    "Ԥ", "ڤ", "", "", "", "", "", "", "", "", "", "ɤ", "ɥ", "ɮ", "ɶ",
    "ɼ", "", "ʬ", "ʬ", "", "", "", "", "", "", "", "", "", "", "",
    "ˡ", "Ω", "Ƭ",
