@@ -51,6 +51,8 @@
 
 NJD_SET_DIGIT_RULE_H_START;
 
+#define NJD_SET_DIGIT_KIGOU "L"
+#define NJD_SET_DIGIT_MEISHI ""
 #define NJD_SET_DIGIT_KAZU ""
 #define NJD_SET_DIGIT_SUUSETSUZOKU "ڑ"
 #define NJD_SET_DIGIT_JOSUUSHI ""
@@ -63,6 +65,7 @@ NJD_SET_DIGIT_RULE_H_START;
 #define NJD_SET_DIGIT_KAKKO1 "i"
 #define NJD_SET_DIGIT_KAKKO2 "j"
 #define NJD_SET_DIGIT_BANGOU "ԍ"
+#define NJD_SET_DIGIT_COMMA "C"
 #define NJD_SET_DIGIT_TEN1 "D"
 #define NJD_SET_DIGIT_TEN2 "E"
 #define NJD_SET_DIGIT_TEN_FEATURE "D,,ڔ,,*,*,*,D,e,e,0/2,*,-1"
@@ -76,6 +79,7 @@ NJD_SET_DIGIT_RULE_H_START;
 #define NJD_SET_DIGIT_FIVE ""
 #define NJD_SET_DIGIT_FIVE_BEFORE_DP "S["
 #define NJD_SET_DIGIT_FIVE_AFTER_DP "S["
+#define NJD_SET_DIGIT_SIX "Z"
 #define NJD_SET_DIGIT_NIN "l"
 #define NJD_SET_DIGIT_GATSU ""
 #define NJD_SET_DIGIT_NICHI ""
@@ -305,7 +309,7 @@ static const char *njd_set_digit_rule_numerative_class1g[] = {
    "", "", "", "", "", "", "", "", "", "C", "JC", "\", "p",
    "", "", "", "", "", "і", "", "", "", "", "@", "C", "G", "R",
    "q", "r", "", "", "", "", "", "", "d", "", "", "", "", "", "v",
-   "", "P^", "Z", "`", "s", "", "g", "", "", "", "", "", "N", "",
+   "", "P^", "Z", "`", /* "s", */ "", "g", "", "", "", "", "", "N", "",
    "҂", "؂", "g", "h", "s", "t", "", "", "", "", "", "C", "D", "M", "U",
    "[", "i", "", "", "", "", "", "", "", "", "", "", "", "", "",
    "@", "{", "g",
