@@ -4,7 +4,7 @@
 /*           http://open-jtalk.sourceforge.net/                      */
 /* ----------------------------------------------------------------- */
 /*                                                                   */
-/*  Copyright (c) 2008-2013  Nagoya Institute of Technology          */
+/*  Copyright (c) 2008-2016  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -82,25 +82,6 @@ static const char *njd_set_long_vowel_table[] = {
    "xC", "x[",
    "yC", "y[",
    "C", "[",
-   /*
-      "FC", "F[",
-      "FC", "F[",
-      "~FC", "~F[",
-      "tFC", "tF[",
-      "sFC", "sF[",
-      "rFC", "rF[",
-      "qFC", "qF[",
-      "jFC", "jF[",
-      "fFC", "fF[",
-      "cFC", "cF[",
-      "`FC", "`F[",
-      "WFC", "WF[",
-      "VFC", "VF[",
-      "MFC", "MF[",
-      "LFC", "LF[",
-      "EFC", "EF[",
-      "CFC", "CF[",
-    */
    NULL, NULL
 };
 
