@@ -4,7 +4,7 @@
 /*           http://open-jtalk.sourceforge.net/                      */
 /* ----------------------------------------------------------------- */
 /*                                                                   */
-/*  Copyright (c) 2008-2013  Nagoya Institute of Technology          */
+/*  Copyright (c) 2008-2016  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -136,7 +136,6 @@ static const char *njd_set_pronunciation_list[] = {
    "\xa5\xc7\xa5\xe7", "\xa5\xc7\xa5\xe7", "1",
    "\xa5\xc7\xa5\xe5", "\xa5\xc7\xa5\xe5", "1",
    "\xa5\xc7\xa5\xe3", "\xa5\xc7\xa5\xe3", "1",
-   "\xa5\xc7\xa5\xa7", "\xa5\xc7\xa5\xa7", "1",
    "\xa5\xc7\xa5\xa3", "\xa5\xc7\xa5\xa3", "1",
    "\xa5\xc7", "\xa5\xc7", "1",
    "\xa5\xc6\xa5\xe7", "\xa5\xc6\xa5\xe7", "1",
@@ -211,6 +210,14 @@ static const char *njd_set_pronunciation_list[] = {
    "\xa5\xa3", "\xa5\xa3", "1",
    "\xa5\xa2", "\xa5\xa2", "1",
    "\xa5\xa1", "\xa5\xa1", "1",
+   "\xa5\xf4\xa4\xe7", "\xa5\xf4\xa5\xe7", "1", /* none in this charcode */
+   "\xa5\xf4\xa4\xe5", "\xa5\xf4\xa5\xe5", "1", /* none in this charcode */
+   "\xa5\xf4\xa4\xe3", "\xa5\xf4\xa5\xe3", "1", /* none in this charcode */
+   "\xa5\xf4\xa4\xa9", "\xa5\xf4\xa5\xa9", "1", /* none in this charcode */
+   "\xa5\xf4\xa4\xa7", "\xa5\xf4\xa5\xa7", "1", /* none in this charcode */
+   "\xa5\xf4\xa4\xa3", "\xa5\xf4\xa5\xa3", "1", /* none in this charcode */
+   "\xa5\xf4\xa4\xa1", "\xa5\xf4\xa5\xa1", "1", /* none in this charcode */
+   "\xa5\xf4", "\xa5\xf4", "1", /* none in this charcode */
    "\xa4\xf3", "\xa5\xf3", "1",
    "\xa4\xf2", "\xa5\xf2", "1",
    "\xa4\xf1", "\xa5\xf1", "1",
@@ -287,7 +294,6 @@ static const char *njd_set_pronunciation_list[] = {
    "\xa4\xc7\xa4\xe7", "\xa5\xc7\xa5\xe7", "1",
    "\xa4\xc7\xa4\xe5", "\xa5\xc7\xa5\xe5", "1",
    "\xa4\xc7\xa4\xe3", "\xa5\xc7\xa5\xe3", "1",
-   "\xa4\xc7\xa4\xa7", "\xa5\xc7\xa5\xa7", "1",
    "\xa4\xc7\xa4\xa3", "\xa5\xc7\xa5\xa3", "1",
    "\xa4\xc7", "\xa5\xc7", "1",
    "\xa4\xc6\xa4\xe7", "\xa5\xc6\xa5\xe7", "1",
@@ -387,7 +393,7 @@ static const char *njd_set_pronunciation_list[] = {
    "\xa3\xe4", "\xa5\xc7\xa5\xa3\xa1\xbc", "2",
    "\xa3\xe3", "\xa5\xb7\xa1\xbc", "2",
    "\xa3\xe2", "\xa5\xd3\xa1\xbc", "2",
-   "\xa3\xe1", "\xa5\xa8\xa5\xa4", "2",
+   "\xa3\xe1", "\xa5\xa8\xa1\xbc", "2",
    "\xa3\xda", "\xa5\xba\xa5\xa3\xa1\xbc", "2",
    "\xa3\xd9", "\xa5\xef\xa5\xa4", "2",
    "\xa3\xd8", "\xa5\xa8\xa5\xc3\xa5\xaf\xa5\xb9", "4",
@@ -413,7 +419,7 @@ static const char *njd_set_pronunciation_list[] = {
    "\xa3\xc4", "\xa5\xc7\xa5\xa3\xa1\xbc", "2",
    "\xa3\xc3", "\xa5\xb7\xa1\xbc", "2",
    "\xa3\xc2", "\xa5\xd3\xa1\xbc", "2",
-   "\xa3\xc1", "\xa5\xa8\xa5\xa4", "2",
+   "\xa3\xc1", "\xa5\xa8\xa1\xbc", "2",
    "\xa1\xbc", "\xa1\xbc", "1",
    NULL, NULL, NULL
 };
@@ -422,97 +428,12 @@ static const char *njd_set_pronunciation_list[] = {
 #define NJD_SET_PRONUNCIATION_KAZU "\xbf\xf4"
 
 static const char *njd_set_pronunciation_symbol_list[] = {
-   "\xa1\xa1", "\xa1\xa2",
-   "\xa1\xa2", "\xa1\xa2",
-   "\xa1\xa3", "\xa1\xa2",
-   "\xa1\xa4", "\xa1\xa2",
-   "\xa1\xa5", "\xa1\xa2",
-   "\xa1\xa6", "\xa1\xa2",
-   "\xa1\xa7", "\xa1\xa2",
-   "\xa1\xa8", "\xa1\xa2",
    "\xa1\xa9", "\xa1\xa9",
-   "\xa1\xaa", "\xa1\xa2",
-   "\xa1\xab", "\xa1\xa2",
-   "\xa1\xac", "\xa1\xa2",
-   "\xa1\xad", "\xa1\xa2",
-   "\xa1\xae", "\xa1\xa2",
-   "\xa1\xaf", "\xa1\xa2",
-   "\xa1\xb0", "\xa1\xa2",
-   "\xa1\xb1", "\xa1\xa2",
-   "\xa1\xb2", "\xa1\xa2",
-   "\xa1\xb3", "\xa1\xa2",
-   "\xa1\xb4", "\xa1\xa2",
-   "\xa1\xb5", "\xa1\xa2",
-   "\xa1\xb6", "\xa1\xa2",
-   "\xa1\xb7", "\xa1\xa2",
-   "\xa1\xb8", "\xa1\xa2",
-   "\xa1\xb9", "\xa1\xa2",
-   "\xa1\xb9\xa1\xb9", "\xa1\xa2",
-   "\xa1\xba", "\xa1\xa2",
-   "\xa1\xbb", "\xa1\xa2",
-   "\xa1\xbd", "\xa1\xa2",
-   "\xa1\xbd\xa1\xbd", "\xa1\xa2",
-   "\xa1\xbe", "\xa1\xa2",
-   "\xa1\xbf", "\xa1\xa2",
-   "\xa1\xc0", "\xa1\xa2",
-   "\xa1\xc1", "\xa1\xa2",
-   "\xa1\xc2", "\xa1\xa2",
-   "\xa1\xc3", "\xa1\xa2",
-   "\xa1\xc4", "\xa1\xa2",
-   "\xa1\xc5", "\xa1\xa2",
-   "\xa1\xc6", "\xa1\xa2",
-   "\xa1\xc7", "\xa1\xa2",
-   "\xa1\xc8", "\xa1\xa2",
-   "\xa1\xc9", "\xa1\xa2",
-   "\xa1\xca", "\xa1\xa2",
-   "\xa1\xcb", "\xa1\xa2",
-   "\xa1\xcc", "\xa1\xa2",
-   "\xa1\xcd", "\xa1\xa2",
-   "\xa1\xce", "\xa1\xa2",
-   "\xa1\xcf", "\xa1\xa2",
-   "\xa1\xd0", "\xa1\xa2",
-   "\xa1\xd1", "\xa1\xa2",
-   "\xa1\xd2", "\xa1\xa2",
-   "\xa1\xd3", "\xa1\xa2",
-   "\xa1\xd4", "\xa1\xa2",
-   "\xa1\xd5", "\xa1\xa2",
-   "\xa1\xd6", "\xa1\xa2",
-   "\xa1\xd7", "\xa1\xa2",
-   "\xa1\xd8", "\xa1\xa2",
-   "\xa1\xd9", "\xa1\xa2",
-   "\xa1\xda", "\xa1\xa2",
-   "\xa1\xdb", "\xa1\xa2",
-   "\xa1\xdd\xa1\xdd", "\xa1\xa2",
-   "\xa1\xe1", "\xa1\xa2",
-   "\xa1\xe3", "\xa1\xa2",
-   "\xa1\xe4", "\xa1\xa2",
-   "\xa1\xec", "\xa1\xa2",
-   "\xa1\xf6", "\xa1\xa2",
-   "\xa1\xf9", "\xa1\xa2",
-   "\xa1\xfa", "\xa1\xa2",
-   "\xa1\xfb", "\xa1\xa2",
-   "\xa1\xfc", "\xa1\xa2",
-   "\xa1\xfd", "\xa1\xa2",
-   "\xa1\xfe", "\xa1\xa2",
-   "\xa2\xa1", "\xa1\xa2",
-   "\xa2\xa2", "\xa1\xa2",
-   "\xa2\xa3", "\xa1\xa2",
-   "\xa2\xa4", "\xa1\xa2",
-   "\xa2\xa5", "\xa1\xa2",
-   "\xa2\xa6", "\xa1\xa2",
-   "\xa2\xa7", "\xa1\xa2",
-   "\xa2\xa8", "\xa1\xa2",
-   "\xa2\xaa", "\xa1\xa2",
-   "\xa2\xab", "\xa1\xa2",
-   "\xa2\xac", "\xa1\xa2",
-   "\xa2\xad", "\xa1\xa2",
-   "\xa2\xae", "\xa1\xa2",
-   "\xa8\xa1", "\xa1\xa2",
-   "\xa8\xa1\xa8\xa1", "\xa1\xa2",
-   "\xa1\xdd", "\xa1\xa2",
    NULL, NULL
 };
 
+#define NJD_SET_PRONUNCIATION_FILLER "\xa5\xd5\xa5\xa3\xa5\xe9\xa1\xbc"
+
 #define NJD_SET_PRONUNCIATION_U        "\xa5\xa6"
 #define NJD_SET_PRONUNCIATION_DOUSHI   "\xc6\xb0\xbb\xec"
 #define NJD_SET_PRONUNCIATION_JODOUSHI "\xbd\xf5\xc6\xb0\xbb\xec"
@@ -524,6 +445,8 @@ static const char *njd_set_pronunciation_symbol_list[] = {
 #define NJD_SET_PRONUNCIATION_DESU_PRON "\xa5\xc7\xa5\xb9"
 #define NJD_SET_PRONUNCIATION_MASU_PRON "\xa5\xde\xa5\xb9"
 
+#define NJD_SET_PRONUNCIATION_TOUTEN "\xa1\xa2"
+
 NJD_SET_PRONUNCIATION_RULE_H_END;
 
 #endif                          /* !NJD_SET_PRONUNCIATION_RULE_H */
