@@ -4,7 +4,7 @@
 /*           http://open-jtalk.sourceforge.net/                      */
 /* ----------------------------------------------------------------- */
 /*                                                                   */
-/*  Copyright (c) 2008-2013  Nagoya Institute of Technology          */
+/*  Copyright (c) 2008-2016  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -136,7 +136,6 @@ static const char *njd_set_pronunciation_list[] = {
    "\x83\x66\x83\x87", "\x83\x66\x83\x87", "1",
    "\x83\x66\x83\x85", "\x83\x66\x83\x85", "1",
    "\x83\x66\x83\x83", "\x83\x66\x83\x83", "1",
-   "\x83\x66\x83\x46", "\x83\x66\x83\x46", "1",
    "\x83\x66\x83\x42", "\x83\x66\x83\x42", "1",
    "\x83\x66", "\x83\x66", "1",
    "\x83\x65\x83\x87", "\x83\x65\x83\x87", "1",
@@ -211,6 +210,14 @@ static const char *njd_set_pronunciation_list[] = {
    "\x83\x42", "\x83\x42", "1",
    "\x83\x41", "\x83\x41", "1",
    "\x83\x40", "\x83\x40", "1",
+   "\x83\x94\x82\xe5", "\x83\x94\x83\x87", "1", /* none in this charcode */
+   "\x83\x94\x82\xe3", "\x83\x94\x83\x85", "1", /* none in this charcode */
+   "\x83\x94\x82\xe1", "\x83\x94\x83\x83", "1", /* none in this charcode */
+   "\x83\x94\x82\xa7", "\x83\x94\x83\x48", "1", /* none in this charcode */
+   "\x83\x94\x82\xa5", "\x83\x94\x83\x46", "1", /* none in this charcode */
+   "\x83\x94\x82\xa1", "\x83\x94\x83\x42", "1", /* none in this charcode */
+   "\x83\x94\x82\x9f", "\x83\x94\x83\x40", "1", /* none in this charcode */
+   "\x83\x94", "\x83\x94", "1", /* none in this charcode */
    "\x82\xf1", "\x83\x93", "1",
    "\x82\xf0", "\x83\x92", "1",
    "\x82\xef", "\x83\x91", "1",
@@ -287,7 +294,6 @@ static const char *njd_set_pronunciation_list[] = {
    "\x82\xc5\x82\xe5", "\x83\x66\x83\x87", "1",
    "\x82\xc5\x82\xe3", "\x83\x66\x83\x85", "1",
    "\x82\xc5\x82\xe1", "\x83\x66\x83\x83", "1",
-   "\x82\xc5\x82\xa5", "\x83\x66\x83\x46", "1",
    "\x82\xc5\x82\xa1", "\x83\x66\x83\x42", "1",
    "\x82\xc5", "\x83\x66", "1",
    "\x82\xc4\x82\xe5", "\x83\x65\x83\x87", "1",
@@ -387,7 +393,7 @@ static const char *njd_set_pronunciation_list[] = {
    "\x82\x84", "\x83\x66\x83\x42\x81\x5b", "2",
    "\x82\x83", "\x83\x56\x81\x5b", "2",
    "\x82\x82", "\x83\x72\x81\x5b", "2",
-   "\x82\x81", "\x83\x47\x83\x43", "2",
+   "\x82\x81", "\x83\x47\x81\x5b", "2",
    "\x82\x79", "\x83\x59\x83\x42\x81\x5b", "2",
    "\x82\x78", "\x83\x8f\x83\x43", "2",
    "\x82\x77", "\x83\x47\x83\x62\x83\x4e\x83\x58", "4",
@@ -413,7 +419,7 @@ static const char *njd_set_pronunciation_list[] = {
    "\x82\x63", "\x83\x66\x83\x42\x81\x5b", "2",
    "\x82\x62", "\x83\x56\x81\x5b", "2",
    "\x82\x61", "\x83\x72\x81\x5b", "2",
-   "\x82\x60", "\x83\x47\x83\x43", "2",
+   "\x82\x60", "\x83\x47\x81\x5b", "2",
    "\x81\x5b", "\x81\x5b", "1",
    NULL, NULL, NULL
 };
@@ -422,97 +428,12 @@ static const char *njd_set_pronunciation_list[] = {
 #define NJD_SET_PRONUNCIATION_KAZU "\x90\x94"
 
 static const char *njd_set_pronunciation_symbol_list[] = {
-   "\x81\x40", "\x81\x41",
-   "\x81\x41", "\x81\x41",
-   "\x81\x42", "\x81\x41",
-   "\x81\x43", "\x81\x41",
-   "\x81\x44", "\x81\x41",
-   "\x81\x45", "\x81\x41",
-   "\x81\x46", "\x81\x41",
-   "\x81\x47", "\x81\x41",
    "\x81\x48", "\x81\x48",
-   "\x81\x49", "\x81\x41",
-   "\x81\x4a", "\x81\x41",
-   "\x81\x4b", "\x81\x41",
-   "\x81\x4c", "\x81\x41",
-   "\x81\x4d", "\x81\x41",
-   "\x81\x4e", "\x81\x41",
-   "\x81\x4f", "\x81\x41",
-   "\x81\x50", "\x81\x41",
-   "\x81\x51", "\x81\x41",
-   "\x81\x52", "\x81\x41",
-   "\x81\x53", "\x81\x41",
-   "\x81\x54", "\x81\x41",
-   "\x81\x55", "\x81\x41",
-   "\x81\x56", "\x81\x41",
-   "\x81\x57", "\x81\x41",
-   "\x81\x58", "\x81\x41",
-   "\x81\x58\x81\x58", "\x81\x41",
-   "\x81\x59", "\x81\x41",
-   "\x81\x5a", "\x81\x41",
-   "\x81\x5c", "\x81\x41",
-   "\x81\x5c\x81\x5c", "\x81\x41",
-   "\x81\x5d", "\x81\x41",
-   "\x81\x5e", "\x81\x41",
-   "\x81\x5f", "\x81\x41",
-   "\x81\x60", "\x81\x41",
-   "\x81\x61", "\x81\x41",
-   "\x81\x62", "\x81\x41",
-   "\x81\x63", "\x81\x41",
-   "\x81\x64", "\x81\x41",
-   "\x81\x65", "\x81\x41",
-   "\x81\x66", "\x81\x41",
-   "\x81\x67", "\x81\x41",
-   "\x81\x68", "\x81\x41",
-   "\x81\x69", "\x81\x41",
-   "\x81\x6a", "\x81\x41",
-   "\x81\x6b", "\x81\x41",
-   "\x81\x6c", "\x81\x41",
-   "\x81\x6d", "\x81\x41",
-   "\x81\x6e", "\x81\x41",
-   "\x81\x6f", "\x81\x41",
-   "\x81\x70", "\x81\x41",
-   "\x81\x71", "\x81\x41",
-   "\x81\x72", "\x81\x41",
-   "\x81\x73", "\x81\x41",
-   "\x81\x74", "\x81\x41",
-   "\x81\x75", "\x81\x41",
-   "\x81\x76", "\x81\x41",
-   "\x81\x77", "\x81\x41",
-   "\x81\x78", "\x81\x41",
-   "\x81\x79", "\x81\x41",
-   "\x81\x7a", "\x81\x41",
-   "\x81\x7c\x81\x7c", "\x81\x41",
-   "\x81\x81", "\x81\x41",
-   "\x81\x83", "\x81\x41",
-   "\x81\x84", "\x81\x41",
-   "\x81\x8c", "\x81\x41",
-   "\x81\x96", "\x81\x41",
-   "\x81\x99", "\x81\x41",
-   "\x81\x9a", "\x81\x41",
-   "\x81\x9b", "\x81\x41",
-   "\x81\x9c", "\x81\x41",
-   "\x81\x9d", "\x81\x41",
-   "\x81\x9e", "\x81\x41",
-   "\x81\x9f", "\x81\x41",
-   "\x81\xa0", "\x81\x41",
-   "\x81\xa1", "\x81\x41",
-   "\x81\xa2", "\x81\x41",
-   "\x81\xa3", "\x81\x41",
-   "\x81\xa4", "\x81\x41",
-   "\x81\xa5", "\x81\x41",
-   "\x81\xa6", "\x81\x41",
-   "\x81\xa8", "\x81\x41",
-   "\x81\xa9", "\x81\x41",
-   "\x81\xaa", "\x81\x41",
-   "\x81\xab", "\x81\x41",
-   "\x81\xac", "\x81\x41",
-   "\x84\x9f", "\x81\x41",
-   "\x84\x9f\x84\x9f", "\x81\x41",
-   "\x81\x7c", "\x81\x41",
    NULL, NULL
 };
 
+#define NJD_SET_PRONUNCIATION_FILLER "\x83\x74\x83\x42\x83\x89\x81\x5b"
+
 #define NJD_SET_PRONUNCIATION_U        "\x83\x45"
 #define NJD_SET_PRONUNCIATION_DOUSHI   "\x93\xae\x8e\x8c"
 #define NJD_SET_PRONUNCIATION_JODOUSHI "\x8f\x95\x93\xae\x8e\x8c"
@@ -524,6 +445,8 @@ static const char *njd_set_pronunciation_symbol_list[] = {
 #define NJD_SET_PRONUNCIATION_DESU_PRON "\x83\x66\x83\x58"
 #define NJD_SET_PRONUNCIATION_MASU_PRON "\x83\x7d\x83\x58"
 
+#define NJD_SET_PRONUNCIATION_TOUTEN "\x81\x41"
+
 NJD_SET_PRONUNCIATION_RULE_H_END;
 
 #endif                          /* !NJD_SET_PRONUNCIATION_RULE_H */
