@@ -4,7 +4,7 @@
 /*           http://open-jtalk.sourceforge.net/                      */
 /* ----------------------------------------------------------------- */
 /*                                                                   */
-/*  Copyright (c) 2008-2013  Nagoya Institute of Technology          */
+/*  Copyright (c) 2008-2016  Nagoya Institute of Technology          */
 /*                           Department of Computer Science          */
 /*                                                                   */
 /* All rights reserved.                                              */
@@ -53,42 +53,52 @@ NJD_SET_UNVOICED_VOWEL_RULE_H_START;
 
 /*
   q: k ky s sh t ty ch ts h f hy p py
-  Rule 1 ́ułvƁu܂v́uv (C)
-  Rule 2 ĖȂ
-  Rule 3 ANZgjŖȂ
-  Rule 4 q(k ky s sh t ty ch ts h f hy p py)Ɉ͂܂ꂽuivƁuuv
+  Rule 0 tB[͖Ȃ
+  Rule 1 ́ułvƁu܂v́uv
+  Rule 2 CĆuv͖₷
+  Rule 3 ĖȂ
+  Rule 4 ANZgjŖȂ
+  Rule 5 q(k ky s sh t ty ch ts h f hy p py)Ɉ͂܂ꂽuivƁuuv
          OFs->s, s->sh, f->f, f->h, f->hy, h->f, h->h, h->hy
 */
 
-#define NJD_SET_UNVOICED_VOWEL_QUOTATION "f"
-#define NJD_SET_UNVOICED_VOWEL_QUESTION "H"
-#define NJD_SET_UNVOICED_VOWEL_TOUTEN "A"
-
+#define NJD_SET_UNVOICED_VOWEL_FILLER "tB["
+#define NJD_SET_UNVOICED_VOWEL_DOUSHI ""
 #define NJD_SET_UNVOICED_VOWEL_JODOUSHI ""
+#define NJD_SET_UNVOICED_VOWEL_JOSHI ""
+#define NJD_SET_UNVOICED_VOWEL_KANDOUSHI ""
+#define NJD_SET_UNVOICED_VOWEL_TOUTEN "A"
+#define NJD_SET_UNVOICED_VOWEL_QUESTION "H"
+#define NJD_SET_UNVOICED_VOWEL_QUOTATION "f"
+#define NJD_SET_UNVOICED_VOWEL_SHI "V"
+#define NJD_SET_UNVOICED_VOWEL_MA "}"
+#define NJD_SET_UNVOICED_VOWEL_DE "f"
+#define NJD_SET_UNVOICED_VOWEL_CHOUON "["
+#define NJD_SET_UNVOICED_VOWEL_SU "X"
 
 static const char *njd_set_unvoiced_vowel_candidate_list1[] = {
-   "XB",                      /* s i */
-   "X",                        /* s u */
+   "XB",                    /* s i */
+   "X",                       /* s u */
    NULL
 };
 
 static const char *njd_set_unvoiced_vowel_next_mora_list1[] = {
-   "J",                        /* k ky */
+   "J",                       /* k ky */
    "L",
    "N",
    "P",
    "R",
-   "^",                        /* t ty ch ts */
+   "^",                       /* t ty ch ts */
    "`",
    "c",
    "e",
    "g",
-   "n",                        /* h f hy */
+   "n",                       /* h f hy */
    "q",
    "t",
    "w",
    "z",
-   "p",                        /* p py */
+   "p",                       /* p py */
    "s",
    "v",
    "y",
@@ -97,29 +107,29 @@ static const char *njd_set_unvoiced_vowel_next_mora_list1[] = {
 };
 
 static const char *njd_set_unvoiced_vowel_candidate_list2[] = {
-   "tB",                      /* f i */
-   "q",                        /* h i */
-   "t",                        /* f u */
+   "tB",                    /* f i */
+   "q",                       /* h i */
+   "t",                       /* f u */
    NULL
 };
 
 static const char *njd_set_unvoiced_vowel_next_mora_list2[] = {
-   "J",                        /* k ky */
+   "J",                       /* k ky */
    "L",
    "N",
    "P",
    "R",
-   "T",                        /* s sh */
+   "T",                       /* s sh */
    "V",
    "X",
    "Z",
    "\",
-   "^",                        /* t ty ch ts */
+   "^",                       /* t ty ch ts */
    "`",
    "c",
    "e",
    "g",
-   "p",                        /* p py */
+   "p",                       /* p py */
    "s",
    "v",
    "y",
@@ -128,47 +138,47 @@ static const char *njd_set_unvoiced_vowel_next_mora_list2[] = {
 };
 
 static const char *njd_set_unvoiced_vowel_candidate_list3[] = {
-   "L",                      /* ky u */
-   "V",                      /* sh u */
-   "`",                      /* ch u */
-   "cB",                      /* ts i */
-   "q",                      /* hy u */
-   "s",                      /* py u */
-   "e",                      /* ty u */
-   "gD",                      /* t u */
-   "eB",                      /* t i */
-   "L",                        /* k i */
-   "N",                        /* k u */
-   "V",                        /* sh i */
-   "`",                        /* ch i */
-   "c",                        /* ts u */
-   "s",                        /* p i */
-   "v",                        /* p u */
+   "L",                    /* ky u */
+   "V",                    /* sh u */
+   "`",                    /* ch u */
+   "cB",                    /* ts i */
+   "q",                    /* hy u */
+   "s",                    /* py u */
+   "e",                    /* ty u */
+   "gD",                    /* t u */
+   "eB",                    /* t i */
+   "L",                       /* k i */
+   "N",                       /* k u */
+   "V",                       /* sh i */
+   "`",                       /* ch i */
+   "c",                       /* ts u */
+   "s",                       /* p i */
+   "v",                       /* p u */
    NULL
 };
 
 static const char *njd_set_unvoiced_vowel_next_mora_list3[] = {
-   "J",                        /* k ky */
+   "J",                       /* k ky */
    "L",
    "N",
    "P",
    "R",
-   "T",                        /* s sh */
+   "T",                       /* s sh */
    "V",
    "X",
    "Z",
    "\",
-   "^",                        /* t ty ch ts */
+   "^",                       /* t ty ch ts */
    "`",
    "c",
    "e",
    "g",
-   "n",                        /* h f hy */
+   "n",                       /* h f hy */
    "q",
    "t",
    "w",
    "z",
-   "p",                        /* p py */
+   "p",                       /* p py */
    "s",
    "v",
    "y",
@@ -261,7 +271,6 @@ static const char *njd_set_unvoiced_vowel_mora_list[] = {
    "f",
    "f",
    "f",
-   "fF",
    "fB",
    "f",
    "e",
